QAD
=======================

QAD is a quick and dirty web application scanner to pick up on low hanging
fruit which may be beneficial to clients if mentioned in a pentest report.

QAD is not multi-threaded and tries to be minimalist in output. It will
process response headers, enumerate a small list of common (and potentially
interesting) directories, and will advise if login or registration forms are
available over a HTTP connection.

----

This is the README file for the project.

The file should use UTF-8 encoding and be written using ReStructured Text. It
will be used to generate the project webpage on PyPI and will be displayed as
the project homepage on common code-hosting services, and should be written for
that purpose.

Typical contents for this file would include an overview of the project, basic
usage examples, etc. Generally, including the project changelog in here is not
a good idea, although a simple "What's New" section for the most recent version
may be appropriate.

